summaryrefslogtreecommitdiffstats
path: root/chromeos/dbus/debug_daemon_client.h
diff options
context:
space:
mode:
authorrkc@chromium.org <rkc@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-08-10 14:11:42 +0000
committerrkc@chromium.org <rkc@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-08-10 14:11:42 +0000
commitf86c6d0caf5f2fd3f11e7b4b71898d50de936889 (patch)
tree32c908eb0e9f59795a032578a01f6d3046a14c68 /chromeos/dbus/debug_daemon_client.h
parent07fb4fbcc613f2245266ed1597773e47f847302a (diff)
downloadchromium_src-f86c6d0caf5f2fd3f11e7b4b71898d50de936889.zip
chromium_src-f86c6d0caf5f2fd3f11e7b4b71898d50de936889.tar.gz
chromium_src-f86c6d0caf5f2fd3f11e7b4b71898d50de936889.tar.bz2
Use scrubbed logs for sending with feedback reports.
owners reviews requested, ui/webui/ - xiyuan@ chromeos/ - stevenjb@ chrome/browser/extensions/ - asargent@ R=asargent@chromium.org, stevenjb@chromium.org, xiyuan@chromium.org BUG=270291 TEST=Test that the system_info page and feedback reports show different logs where scrubbing is concerned (tested with the stub lib). Review URL: https://chromiumcodereview.appspot.com/22532012 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@216851 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chromeos/dbus/debug_daemon_client.h')
-rw-r--r--chromeos/dbus/debug_daemon_client.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/chromeos/dbus/debug_daemon_client.h b/chromeos/dbus/debug_daemon_client.h
index 92652e3..7c09a78 100644
--- a/chromeos/dbus/debug_daemon_client.h
+++ b/chromeos/dbus/debug_daemon_client.h
@@ -95,11 +95,14 @@ class CHROMEOS_EXPORT DebugDaemonClient {
virtual void GetPerfData(uint32_t duration,
const GetPerfDataCallback& callback) = 0;
// Callback type for GetAllLogs() or GetUserLogFiles().
typedef base::Callback<void(bool succeeded,
const std::map<std::string, std::string>& logs)>
GetLogsCallback;
+ // Gets scrubbed logs from debugd.
+ virtual void GetScrubbedLogs(const GetLogsCallback& callback) = 0;
+
// Gets all logs collected by debugd.
virtual void GetAllLogs(const GetLogsCallback& callback) = 0;
@@ -95,11 +95,14 @@ class CHROMEOS_EXPORT DebugDaemonClient {
virtual void GetPerfData(uint32_t duration,
const GetPerfDataCallback& callback) = 0;
- // Callback type for GetAllLogs() or GetUserLogFiles().
+ // Callback type for GetScrubbedLogs(), GetAllLogs() or GetUserLogFiles().
typedef base::Callback<void(bool succeeded,
const std::map<std::string, std::string>& logs)>